@@ -156,7 +156,7 @@ gst_rtsp_media_factory_class_init (GstRTSPMediaFactoryClass * klass)
    * default prepare vmethod.
    *
    * The pipeline description should return a GstBin as the toplevel element
-   * which can be accomplished by enclosing the dscription with brackets '('
+   * which can be accomplished by enclosing the description with brackets '('
    * ')'.
    *
    * The description should return a pipeline with payloaders named pay0, pay1,
@@ -411,7 +411,7 @@ gst_rtsp_media_factory_new (void)
 /**
  * gst_rtsp_media_factory_set_permissions:
  * @factory: a #GstRTSPMediaFactory
- * @permissions: (transfer none): a #GstRTSPPermissions
+ * @permissions: (transfer none) (nullable): a #GstRTSPPermissions
  *
  * Set @permissions on @factory.
  */
@@ -439,7 +439,7 @@ gst_rtsp_media_factory_set_permissions (GstRTSPMediaFactory * factory,
  *
  * Get the permissions object from @factory.
  *
- * Returns: (transfer full): a #GstRTSPPermissions object, unref after usage.
+ * Returns: (transfer full) (nullable): a #GstRTSPPermissions object, unref after usage.
  */
 GstRTSPPermissions *
 gst_rtsp_media_factory_get_permissions (GstRTSPMediaFactory * factory)
@@ -504,7 +504,7 @@ gst_rtsp_media_factory_add_role (GstRTSPMediaFactory * factory,
  * default prepare vmethod.
  *
  * The pipeline description should return a GstBin as the toplevel element
- * which can be accomplished by enclosing the dscription with brackets '('
+ * which can be accomplished by enclosing the description with brackets '('
  * ')'.
  *
  * The description should return a pipeline with payloaders named pay0, pay1,
@@ -534,7 +534,7 @@ gst_rtsp_media_factory_set_launch (GstRTSPMediaFactory * factory,
  * Get the gst_parse_launch() pipeline description that will be used in the
  * default prepare vmethod.
  *
- * Returns: (transfer full): the configured launch description. g_free() after
+ * Returns: (transfer full) (nullable): the configured launch description. g_free() after
  * usage.
  */
 gchar *
@@ -748,7 +748,7 @@ gst_rtsp_media_factory_get_buffer_size (GstRTSPMediaFactory * factory)
 /**
  * gst_rtsp_media_factory_set_address_pool:
  * @factory: a #GstRTSPMediaFactory
- * @pool: (transfer none): a #GstRTSPAddressPool
+ * @pool: (transfer none) (nullable): a #GstRTSPAddressPool
  *
  * configure @pool to be used as the address pool of @factory.
  */
@@ -780,7 +780,7 @@ gst_rtsp_media_factory_set_address_pool (GstRTSPMediaFactory * factory,
  *
  * Get the #GstRTSPAddressPool used as the address pool of @factory.
  *
- * Returns: (transfer full): the #GstRTSPAddressPool of @factory. g_object_unref() after
+ * Returns: (transfer full) (nullable): the #GstRTSPAddressPool of @factory. g_object_unref() after
  * usage.
  */
 GstRTSPAddressPool *
@@ -803,10 +803,10 @@ gst_rtsp_media_factory_get_address_pool (GstRTSPMediaFactory * factory)
 
 /**
  * gst_rtsp_media_factory_set_multicast_iface:
- * @media_factory: a #GstRTSPMediaFactory
- * @multicast_iface: (transfer none): a multicast interface name
+ * @factory: a #GstRTSPMediaFactory
+ * @multicast_iface: (transfer none) (nullable): a multicast interface name
  *
- * configure @multicast_iface to be used for @media_factory.
+ * configure @multicast_iface to be used for @factory.
  */
 void
 gst_rtsp_media_factory_set_multicast_iface (GstRTSPMediaFactory * media_factory,
@@ -834,11 +834,11 @@ gst_rtsp_media_factory_set_multicast_iface (GstRTSPMediaFactory * media_factory,
 
 /**
  * gst_rtsp_media_factory_get_multicast_iface:
- * @media_factory: a #GstRTSPMediaFactory
+ * @factory: a #GstRTSPMediaFactory
  *
- * Get the multicast interface used for @media_factory.
+ * Get the multicast interface used for @factory.
  *
- * Returns: (transfer full): the multicast interface for @media_factory. g_free() after
+ * Returns: (transfer full) (nullable): the multicast interface for @factory. g_free() after
  * usage.
  */
 gchar *
@@ -1216,7 +1216,7 @@ gst_rtsp_media_factory_construct (GstRTSPMediaFactory * factory,
           NULL);
 
       /* check if we can cache this media */
-      if (gst_rtsp_media_is_shared (media)) {
+      if (gst_rtsp_media_is_shared (media) && key) {
         /* insert in the hashtable, takes ownership of the key */
         g_object_ref (media);
         g_hash_table_insert (priv->medias, key, media);
@@ -1292,7 +1292,7 @@ gst_rtsp_media_factory_get_media_gtype (GstRTSPMediaFactory * factory)
 /**
  * gst_rtsp_media_factory_set_clock:
  * @factory: a #GstRTSPMediaFactory
- * @clockd: the clock to be used by the media factory
+ * @clock: (nullable): the clock to be used by the media factory
  *
  * Configures a specific clock to be used by the pipelines
  * of all medias created from this factory.
@@ -1644,7 +1644,7 @@ gst_rtsp_media_factory_set_transport_mode (GstRTSPMediaFactory * factory,
  * Get if media created from this factory can be used for PLAY or RECORD
  * methods.
  *
- * Returns: The supported transport modes.
+ * Returns: The transport mode.
  */
 GstRTSPTransportMode
 gst_rtsp_media_factory_get_transport_mode (GstRTSPMediaFactory * factory)
