@@ -103,12 +103,15 @@ typedef enum {
 } GstRTSPPublishClockMode;
 
 #define GST_TYPE_RTSP_TRANSPORT_MODE (gst_rtsp_transport_mode_get_type())
+GST_EXPORT
 GType gst_rtsp_transport_mode_get_type (void);
 
 #define GST_TYPE_RTSP_SUSPEND_MODE (gst_rtsp_suspend_mode_get_type())
+GST_EXPORT
 GType gst_rtsp_suspend_mode_get_type (void);
 
 #define GST_TYPE_RTSP_PUBLISH_CLOCK_MODE (gst_rtsp_publish_clock_mode_get_type())
+GST_EXPORT
 GType gst_rtsp_publish_clock_mode_get_type (void);
 
 #include "rtsp-stream.h"
@@ -186,107 +189,204 @@ struct _GstRTSPMediaClass {
   gpointer         _gst_reserved[GST_PADDING_LARGE-1];
 };
 
+GST_EXPORT
 GType                 gst_rtsp_media_get_type         (void);
 
 /* creating the media */
+
+GST_EXPORT
 GstRTSPMedia *        gst_rtsp_media_new              (GstElement *element);
+
+GST_EXPORT
 GstElement *          gst_rtsp_media_get_element      (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_take_pipeline    (GstRTSPMedia *media, GstPipeline *pipeline);
 
+GST_EXPORT
 GstRTSPMediaStatus    gst_rtsp_media_get_status       (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_permissions  (GstRTSPMedia *media,
                                                        GstRTSPPermissions *permissions);
+
+GST_EXPORT
 GstRTSPPermissions *  gst_rtsp_media_get_permissions  (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_shared       (GstRTSPMedia *media, gboolean shared);
+
+GST_EXPORT
 gboolean              gst_rtsp_media_is_shared        (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_stop_on_disconnect (GstRTSPMedia *media, gboolean stop_on_disconnect);
+
+GST_EXPORT
 gboolean              gst_rtsp_media_is_stop_on_disconnect  (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_transport_mode  (GstRTSPMedia *media, GstRTSPTransportMode mode);
+
+GST_EXPORT
 GstRTSPTransportMode  gst_rtsp_media_get_transport_mode  (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_reusable     (GstRTSPMedia *media, gboolean reusable);
+
+GST_EXPORT
 gboolean              gst_rtsp_media_is_reusable      (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_profiles     (GstRTSPMedia *media, GstRTSPProfile profiles);
+
+GST_EXPORT
 GstRTSPProfile        gst_rtsp_media_get_profiles     (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_protocols    (GstRTSPMedia *media, GstRTSPLowerTrans protocols);
+
+GST_EXPORT
 GstRTSPLowerTrans     gst_rtsp_media_get_protocols    (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_eos_shutdown (GstRTSPMedia *media, gboolean eos_shutdown);
+
+GST_EXPORT
 gboolean              gst_rtsp_media_is_eos_shutdown  (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_address_pool (GstRTSPMedia *media, GstRTSPAddressPool *pool);
+
+GST_EXPORT
 GstRTSPAddressPool *  gst_rtsp_media_get_address_pool (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_multicast_iface (GstRTSPMedia *media, const gchar *multicast_iface);
+
+GST_EXPORT
 gchar *               gst_rtsp_media_get_multicast_iface (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_buffer_size  (GstRTSPMedia *media, guint size);
+
+GST_EXPORT
 guint                 gst_rtsp_media_get_buffer_size  (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_retransmission_time  (GstRTSPMedia *media, GstClockTime time);
+
+GST_EXPORT
 GstClockTime          gst_rtsp_media_get_retransmission_time  (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_latency      (GstRTSPMedia *media, guint latency);
+
+GST_EXPORT
 guint                 gst_rtsp_media_get_latency      (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_use_time_provider (GstRTSPMedia *media, gboolean time_provider);
+
+GST_EXPORT
 gboolean              gst_rtsp_media_is_time_provider  (GstRTSPMedia *media);
+
+GST_EXPORT
 GstNetTimeProvider *  gst_rtsp_media_get_time_provider (GstRTSPMedia *media,
                                                         const gchar *address, guint16 port);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_clock         (GstRTSPMedia *media, GstClock * clock);
 
 
+GST_EXPORT
 void                    gst_rtsp_media_set_publish_clock_mode (GstRTSPMedia * media, GstRTSPPublishClockMode mode);
+
+GST_EXPORT
 GstRTSPPublishClockMode gst_rtsp_media_get_publish_clock_mode (GstRTSPMedia * media);
 
 /* prepare the media for playback */
+
+GST_EXPORT
 gboolean              gst_rtsp_media_prepare          (GstRTSPMedia *media, GstRTSPThread *thread);
+
+GST_EXPORT
 gboolean              gst_rtsp_media_unprepare        (GstRTSPMedia *media);
 
+GST_EXPORT
 void                  gst_rtsp_media_set_suspend_mode (GstRTSPMedia *media, GstRTSPSuspendMode mode);
+
+GST_EXPORT
 GstRTSPSuspendMode    gst_rtsp_media_get_suspend_mode (GstRTSPMedia *media);
 
+GST_EXPORT
 gboolean              gst_rtsp_media_suspend          (GstRTSPMedia *media);
+
+GST_EXPORT
 gboolean              gst_rtsp_media_unsuspend        (GstRTSPMedia *media);
 
+GST_EXPORT
 gboolean              gst_rtsp_media_setup_sdp        (GstRTSPMedia * media, GstSDPMessage * sdp,
                                                        GstSDPInfo * info);
 
+GST_EXPORT
 gboolean              gst_rtsp_media_handle_sdp (GstRTSPMedia * media, GstSDPMessage * sdp);
 
 
 /* creating streams */
+
+GST_EXPORT
 void                  gst_rtsp_media_collect_streams  (GstRTSPMedia *media);
+
+GST_EXPORT
 GstRTSPStream *       gst_rtsp_media_create_stream    (GstRTSPMedia *media,
                                                        GstElement *payloader,
                                                        GstPad *pad);
 
 /* dealing with the media */
+
+GST_EXPORT
 GstClock *            gst_rtsp_media_get_clock        (GstRTSPMedia *media);
+
+GST_EXPORT
 GstClockTime          gst_rtsp_media_get_base_time    (GstRTSPMedia *media);
 
+GST_EXPORT
 guint                 gst_rtsp_media_n_streams        (GstRTSPMedia *media);
+
+GST_EXPORT
 GstRTSPStream *       gst_rtsp_media_get_stream       (GstRTSPMedia *media, guint idx);
+
+GST_EXPORT
 GstRTSPStream *       gst_rtsp_media_find_stream      (GstRTSPMedia *media, const gchar * control);
 
+GST_EXPORT
 gboolean              gst_rtsp_media_seek             (GstRTSPMedia *media, GstRTSPTimeRange *range);
+
+GST_EXPORT
+gboolean              gst_rtsp_media_seek_full        (GstRTSPMedia *media,
+                                                       GstRTSPTimeRange *range,
+                                                       GstSeekFlags flags);
+
+GST_EXPORT
+GstClockTimeDiff      gst_rtsp_media_seekable         (GstRTSPMedia *media);
+
+GST_EXPORT
 gchar *               gst_rtsp_media_get_range_string (GstRTSPMedia *media,
                                                        gboolean play,
                                                        GstRTSPRangeUnit unit);
 
+GST_EXPORT
 gboolean              gst_rtsp_media_set_state        (GstRTSPMedia *media, GstState state,
                                                        GPtrArray *transports);
+
+GST_EXPORT
 void                  gst_rtsp_media_set_pipeline_state (GstRTSPMedia * media,
                                                          GstState state);
 
+GST_EXPORT
+gboolean              gst_rtsp_media_complete_pipeline (GstRTSPMedia * media, GPtrArray * transports);
+
 #ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstRTSPMedia, gst_object_unref)
 #endif
